==> archive-images-1.0.0.tar.gz: archive-images-1.0.0/README.md <==
# archive-images

## Description

Small python package to create an image archive from a bunch of unordered images. The images are archived on the basis of the timestamp in the exif data.

## Installation

Install with:

```
pip install archive-images
```

Then call the help screen of executable with `archive-images --help`.

## Usage notes

The default target path of an image in the archive is `year/month/%Y_%m_%d_%H_%M_%S.%f.ext`, e.g. `image_archive\2018\04\2018-04-03_17_21_20.219.jpg`. Note that the extension of an image is automatically converted to lowercase, e.g. ``.JPG`` to ``.jpg``.

## Help screen

<!-- Manual formatting needed in order to not exceed 100 char -->

```
usage: archive-images [-h] -i IMAGEFOLDER -a IMAGEARCHIVE [-e IMAGEEXTENSIONS] [-m {copy,move}]
                      [-fs FILTERBYIMAGESIZE FILTERBYIMAGESIZE] [-d] [-n] [-c]

required arguments:
  -i IMAGEFOLDER, --imageFolder IMAGEFOLDER
                        Path to input folder with images to archive. (default: None)
  -a IMAGEARCHIVE, --imageArchive IMAGEARCHIVE
                        Path to output folder with image archive. (default: None)

optional arguments:
  -e IMAGEEXTENSIONS, --imageExtensions IMAGEEXTENSIONS
                        Extensions of images to archive separated by commas.
                        (default: ['jpg', 'jpeg'])
  -m {copy,move}, --mode {copy,move}
                        Move or copy image files to archive? (default: copy)
  -fs FILTERBYIMAGESIZE FILTERBYIMAGESIZE, --filterByImageSize FILTERBYIMAGESIZE FILTERBYIMAGESIZE
                        Archive only images with a specific image size. The image size must be
                        specified as two integer numbers separated by a single space,
                        i.e. num1 num2. The orientation of the images (portrait or landscape) is
                        not considered by this filter, i.e. images with size num1-by-num2 or
                        num2-by-num1 are archived. (default: [0, 0])
  -d, --addDuplicates   Add duplicates to a subfolder "duplicates" in image archive?
                        (default: False)
  -n, --addNoExif       Add images with no exif information to a subfolder "no_exif" in image
                        archive? (default: False)
  -c, --confirm         Confirm each operation before execution? (default: False)
```

==> archive-images-1.0.1.tar.gz: archive-images-1.0.1/README.md <==
# archive-images

[![](https://img.shields.io/pypi/v/archive-images)](https://pypi.org/project/archive-images)

## Description

Small python package to create an image archive from a bunch of unordered images. The images are archived on the basis of the timestamp in the exif data.

## Installation

You can install the simpleicp package from [PyPI](https://pypi.org/project/archive-images/):

```
pip install archive-images
```

Then call the help screen of executable with `archive-images --help`.

## Usage notes

The default target path of an image in the archive is `year/month/%Y_%m_%d_%H_%M_%S.%f.ext`, e.g. `image_archive\2018\04\2018-04-03_17_21_20.219.jpg`. Note that the extension of an image is automatically converted to lowercase, e.g. ``.JPG`` to ``.jpg``.

## Help screen

<!-- Manual formatting needed in order to not exceed 100 char -->

```
usage: archive-images [-h] -i IMAGEFOLDER -a IMAGEARCHIVE [-e IMAGEEXTENSIONS] [-m {copy,move}]
                      [-fs FILTERBYIMAGESIZE FILTERBYIMAGESIZE] [-d] [-n] [-c]

required arguments:
  -i IMAGEFOLDER, --imageFolder IMAGEFOLDER
                        Path to input folder with images to archive. (default: None)
  -a IMAGEARCHIVE, --imageArchive IMAGEARCHIVE
                        Path to output folder with image archive. (default: None)

optional arguments:
  -e IMAGEEXTENSIONS, --imageExtensions IMAGEEXTENSIONS
                        Extensions of images to archive separated by commas.
                        (default: ['jpg', 'jpeg'])
  -m {copy,move}, --mode {copy,move}
                        Move or copy image files to archive? (default: copy)
  -fs FILTERBYIMAGESIZE FILTERBYIMAGESIZE, --filterByImageSize FILTERBYIMAGESIZE FILTERBYIMAGESIZE
                        Archive only images with a specific image size. The image size must be
                        specified as two integer numbers separated by a single space,
                        i.e. num1 num2. The orientation of the images (portrait or landscape) is
                        not considered by this filter, i.e. images with size num1-by-num2 or
                        num2-by-num1 are archived. (default: [0, 0])
  -d, --addDuplicates   Add duplicates to a subfolder "duplicates" in image archive?
                        (default: False)
  -n, --addNoExif       Add images with no exif information to a subfolder "no_exif" in image
                        archive? (default: False)
  -c, --confirm         Confirm each operation before execution? (default: False)
```
